# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'taxonome/gui/ui/combine.ui'
#
# Created: Tue May 29 11:46:18 2012
#      by: PyQt4 UI code generator 4.8.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_CombineDialog(object):
    def setupUi(self, CombineDialog):
        CombineDialog.setObjectName(_fromUtf8("CombineDialog"))
        CombineDialog.resize(587, 460)
        self.verticalLayout_2 = QtGui.QVBoxLayout(CombineDialog)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.label = QtGui.QLabel(CombineDialog)
        self.label.setObjectName(_fromUtf8("label"))
        self.horizontalLayout.addWidget(self.label)
        self.newname = QtGui.QLineEdit(CombineDialog)
        self.newname.setObjectName(_fromUtf8("newname"))
        self.horizontalLayout.addWidget(self.newname)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.groupBox = QtGui.QGroupBox(CombineDialog)
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.verticalLayout_6 = QtGui.QVBoxLayout(self.groupBox)
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        self.splitter = QtGui.QSplitter(self.groupBox)
        self.splitter.setOrientation(QtCore.Qt.Horizontal)
        self.splitter.setObjectName(_fromUtf8("splitter"))
        self.layoutWidget = QtGui.QWidget(self.splitter)
        self.layoutWidget.setObjectName(_fromUtf8("layoutWidget"))
        self.verticalLayout = QtGui.QVBoxLayout(self.layoutWidget)
        self.verticalLayout.setMargin(0)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.horizontalLayout_3 = QtGui.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.label_2 = QtGui.QLabel(self.layoutWidget)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.horizontalLayout_3.addWidget(self.label_2)
        self.target_ds_add = QtGui.QToolButton(self.layoutWidget)
        self.target_ds_add.setAutoRaise(True)
        self.target_ds_add.setObjectName(_fromUtf8("target_ds_add"))
        self.horizontalLayout_3.addWidget(self.target_ds_add)
        self.target_ds_remove = QtGui.QToolButton(self.layoutWidget)
        self.target_ds_remove.setAutoRaise(True)
        self.target_ds_remove.setObjectName(_fromUtf8("target_ds_remove"))
        self.horizontalLayout_3.addWidget(self.target_ds_remove)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.target_ds_list = QtGui.QListView(self.layoutWidget)
        self.target_ds_list.setObjectName(_fromUtf8("target_ds_list"))
        self.verticalLayout.addWidget(self.target_ds_list)
        self.horizontalLayout_4 = QtGui.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.label_3 = QtGui.QLabel(self.layoutWidget)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.horizontalLayout_4.addWidget(self.label_3)
        self.bg_ds_add = QtGui.QToolButton(self.layoutWidget)
        self.bg_ds_add.setAutoRaise(True)
        self.bg_ds_add.setObjectName(_fromUtf8("bg_ds_add"))
        self.horizontalLayout_4.addWidget(self.bg_ds_add)
        self.bg_ds_remove = QtGui.QToolButton(self.layoutWidget)
        self.bg_ds_remove.setAutoRaise(True)
        self.bg_ds_remove.setArrowType(QtCore.Qt.NoArrow)
        self.bg_ds_remove.setObjectName(_fromUtf8("bg_ds_remove"))
        self.horizontalLayout_4.addWidget(self.bg_ds_remove)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.bg_ds_list = QtGui.QListView(self.layoutWidget)
        self.bg_ds_list.setObjectName(_fromUtf8("bg_ds_list"))
        self.verticalLayout.addWidget(self.bg_ds_list)
        self.layoutWidget1 = QtGui.QWidget(self.splitter)
        self.layoutWidget1.setObjectName(_fromUtf8("layoutWidget1"))
        self.verticalLayout_5 = QtGui.QVBoxLayout(self.layoutWidget1)
        self.verticalLayout_5.setMargin(0)
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.label_4 = QtGui.QLabel(self.layoutWidget1)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.verticalLayout_5.addWidget(self.label_4)
        self.available_ds_list = QtGui.QListView(self.layoutWidget1)
        self.available_ds_list.setObjectName(_fromUtf8("available_ds_list"))
        self.verticalLayout_5.addWidget(self.available_ds_list)
        self.verticalLayout_6.addWidget(self.splitter)
        self.verticalLayout_2.addWidget(self.groupBox)
        self.horizontalLayout_2 = QtGui.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.label_5 = QtGui.QLabel(CombineDialog)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.horizontalLayout_2.addWidget(self.label_5)
        self.distrib_ds = QtGui.QComboBox(CombineDialog)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.distrib_ds.sizePolicy().hasHeightForWidth())
        self.distrib_ds.setSizePolicy(sizePolicy)
        self.distrib_ds.setEditable(False)
        self.distrib_ds.setObjectName(_fromUtf8("distrib_ds"))
        self.horizontalLayout_2.addWidget(self.distrib_ds)
        self.verticalLayout_2.addLayout(self.horizontalLayout_2)
        self.nest_info = QtGui.QCheckBox(CombineDialog)
        self.nest_info.setObjectName(_fromUtf8("nest_info"))
        self.verticalLayout_2.addWidget(self.nest_info)
        self.buttonBox = QtGui.QDialogButtonBox(CombineDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.verticalLayout_2.addWidget(self.buttonBox)
        self.label.setBuddy(self.newname)
        self.label_5.setBuddy(self.distrib_ds)

        self.retranslateUi(CombineDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), CombineDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), CombineDialog.reject)
        QtCore.QObject.connect(self.bg_ds_add, QtCore.SIGNAL(_fromUtf8("clicked()")), CombineDialog.add_bg_ds)
        QtCore.QObject.connect(self.bg_ds_remove, QtCore.SIGNAL(_fromUtf8("clicked()")), CombineDialog.remove_bg_ds)
        QtCore.QObject.connect(self.target_ds_add, QtCore.SIGNAL(_fromUtf8("clicked()")), CombineDialog.add_target_ds)
        QtCore.QObject.connect(self.target_ds_remove, QtCore.SIGNAL(_fromUtf8("clicked()")), CombineDialog.remove_target_ds)
        QtCore.QMetaObject.connectSlotsByName(CombineDialog)

    def retranslateUi(self, CombineDialog):
        CombineDialog.setWindowTitle(QtGui.QApplication.translate("CombineDialog", "Combine datasets", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("CombineDialog", "&New name:", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("CombineDialog", "Pick datasets to combine", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setToolTip(QtGui.QApplication.translate("CombineDialog", "All taxa from each target dataset will be included.", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("CombineDialog", "Target datasets", None, QtGui.QApplication.UnicodeUTF8))
        self.target_ds_add.setText(QtGui.QApplication.translate("CombineDialog", " + ", None, QtGui.QApplication.UnicodeUTF8))
        self.target_ds_remove.setText(QtGui.QApplication.translate("CombineDialog", " - ", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setToolTip(QtGui.QApplication.translate("CombineDialog", "Information from background datasets will only be used for taxa in target datasets.", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("CombineDialog", "Background datasets", None, QtGui.QApplication.UnicodeUTF8))
        self.bg_ds_add.setText(QtGui.QApplication.translate("CombineDialog", " + ", None, QtGui.QApplication.UnicodeUTF8))
        self.bg_ds_remove.setText(QtGui.QApplication.translate("CombineDialog", " - ", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("CombineDialog", "Available datasets", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("CombineDialog", "Dataset for &distribution:", None, QtGui.QApplication.UnicodeUTF8))
        self.nest_info.setText(QtGui.QApplication.translate("CombineDialog", "Nest information fields by source dataset (leave off if you want to save as CSV)", None, QtGui.QApplication.UnicodeUTF8))

