# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'taxonome/gui/ui/map_names_wizard.ui'
#
# Created: Tue May 29 11:46:18 2012
#      by: PyQt4 UI code generator 4.8.3
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_MapNamesWizard(object):
    def setupUi(self, MapNamesWizard):
        MapNamesWizard.setObjectName(_fromUtf8("MapNamesWizard"))
        MapNamesWizard.resize(555, 426)
        MapNamesWizard.setAutoFillBackground(False)
        MapNamesWizard.setSizeGripEnabled(True)
        self.datasets_page = QtGui.QWizardPage()
        self.datasets_page.setObjectName(_fromUtf8("datasets_page"))
        self.verticalLayout_4 = QtGui.QVBoxLayout(self.datasets_page)
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.groupBox_2 = QtGui.QGroupBox(self.datasets_page)
        self.groupBox_2.setObjectName(_fromUtf8("groupBox_2"))
        self.verticalLayout_5 = QtGui.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.horizontalLayout_5 = QtGui.QHBoxLayout()
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.from_dataset = QtGui.QRadioButton(self.groupBox_2)
        self.from_dataset.setObjectName(_fromUtf8("from_dataset"))
        self.horizontalLayout_5.addWidget(self.from_dataset)
        self.taxa_dataset = QtGui.QComboBox(self.groupBox_2)
        self.taxa_dataset.setEnabled(False)
        self.taxa_dataset.setObjectName(_fromUtf8("taxa_dataset"))
        self.horizontalLayout_5.addWidget(self.taxa_dataset)
        self.verticalLayout_5.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_6 = QtGui.QHBoxLayout()
        self.horizontalLayout_6.setObjectName(_fromUtf8("horizontalLayout_6"))
        self.from_csv = QtGui.QRadioButton(self.groupBox_2)
        self.from_csv.setChecked(True)
        self.from_csv.setObjectName(_fromUtf8("from_csv"))
        self.horizontalLayout_6.addWidget(self.from_csv)
        self.from_csv_file = QtGui.QLineEdit(self.groupBox_2)
        self.from_csv_file.setEnabled(True)
        self.from_csv_file.setReadOnly(True)
        self.from_csv_file.setObjectName(_fromUtf8("from_csv_file"))
        self.horizontalLayout_6.addWidget(self.from_csv_file)
        self.from_csv_browse = QtGui.QPushButton(self.groupBox_2)
        self.from_csv_browse.setEnabled(True)
        self.from_csv_browse.setObjectName(_fromUtf8("from_csv_browse"))
        self.horizontalLayout_6.addWidget(self.from_csv_browse)
        self.verticalLayout_5.addLayout(self.horizontalLayout_6)
        self.label_4 = QtGui.QLabel(self.groupBox_2)
        self.label_4.setWordWrap(True)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.verticalLayout_5.addWidget(self.label_4)
        self.verticalLayout_4.addWidget(self.groupBox_2)
        self.groupBox_5 = QtGui.QGroupBox(self.datasets_page)
        self.groupBox_5.setObjectName(_fromUtf8("groupBox_5"))
        self.verticalLayout_12 = QtGui.QVBoxLayout(self.groupBox_5)
        self.verticalLayout_12.setObjectName(_fromUtf8("verticalLayout_12"))
        self.horizontalLayout_4 = QtGui.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.to_dataset = QtGui.QRadioButton(self.groupBox_5)
        self.to_dataset.setChecked(True)
        self.to_dataset.setObjectName(_fromUtf8("to_dataset"))
        self.horizontalLayout_4.addWidget(self.to_dataset)
        self.target_dataset = QtGui.QComboBox(self.groupBox_5)
        self.target_dataset.setObjectName(_fromUtf8("target_dataset"))
        self.horizontalLayout_4.addWidget(self.target_dataset)
        self.verticalLayout_12.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_10 = QtGui.QHBoxLayout()
        self.horizontalLayout_10.setObjectName(_fromUtf8("horizontalLayout_10"))
        self.to_tnrs = QtGui.QRadioButton(self.groupBox_5)
        self.to_tnrs.setObjectName(_fromUtf8("to_tnrs"))
        self.horizontalLayout_10.addWidget(self.to_tnrs)
        self.verticalLayout_12.addLayout(self.horizontalLayout_10)
        self.label_2 = QtGui.QLabel(self.groupBox_5)
        self.label_2.setWordWrap(True)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.verticalLayout_12.addWidget(self.label_2)
        self.verticalLayout_4.addWidget(self.groupBox_5)
        spacerItem = QtGui.QSpacerItem(20, 40, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem)
        MapNamesWizard.addPage(self.datasets_page)
        self.csv_import_page = QtGui.QWizardPage()
        self.csv_import_page.setSubTitle(_fromUtf8(""))
        self.csv_import_page.setObjectName(_fromUtf8("csv_import_page"))
        self.verticalLayout = QtGui.QVBoxLayout(self.csv_import_page)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.label_3 = QtGui.QLabel(self.csv_import_page)
        self.label_3.setWordWrap(True)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.verticalLayout.addWidget(self.label_3)
        self.horizontalLayout = QtGui.QHBoxLayout()
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.label = QtGui.QLabel(self.csv_import_page)
        self.label.setTextFormat(QtCore.Qt.AutoText)
        self.label.setObjectName(_fromUtf8("label"))
        self.horizontalLayout.addWidget(self.label)
        self.namefield = QtGui.QComboBox(self.csv_import_page)
        self.namefield.setObjectName(_fromUtf8("namefield"))
        self.horizontalLayout.addWidget(self.namefield)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.groupBox = QtGui.QGroupBox(self.csv_import_page)
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.verticalLayout_3 = QtGui.QVBoxLayout(self.groupBox)
        self.verticalLayout_3.setObjectName(_fromUtf8("verticalLayout_3"))
        self.noauth = QtGui.QRadioButton(self.groupBox)
        self.noauth.setObjectName(_fromUtf8("noauth"))
        self.verticalLayout_3.addWidget(self.noauth)
        self.auth_with_name = QtGui.QRadioButton(self.groupBox)
        self.auth_with_name.setObjectName(_fromUtf8("auth_with_name"))
        self.verticalLayout_3.addWidget(self.auth_with_name)
        self.horizontalLayout_3 = QtGui.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.auth_separate = QtGui.QRadioButton(self.groupBox)
        self.auth_separate.setChecked(True)
        self.auth_separate.setObjectName(_fromUtf8("auth_separate"))
        self.horizontalLayout_3.addWidget(self.auth_separate)
        self.authfield = QtGui.QComboBox(self.groupBox)
        self.authfield.setEnabled(True)
        self.authfield.setObjectName(_fromUtf8("authfield"))
        self.horizontalLayout_3.addWidget(self.authfield)
        self.verticalLayout_3.addLayout(self.horizontalLayout_3)
        self.verticalLayout.addWidget(self.groupBox)
        self.preview_label = QtGui.QLabel(self.csv_import_page)
        self.preview_label.setObjectName(_fromUtf8("preview_label"))
        self.verticalLayout.addWidget(self.preview_label)
        self.preview = QtGui.QTableWidget(self.csv_import_page)
        self.preview.setObjectName(_fromUtf8("preview"))
        self.preview.setColumnCount(0)
        self.preview.setRowCount(0)
        self.verticalLayout.addWidget(self.preview)
        self.horizontalLayout_2 = QtGui.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.label_6 = QtGui.QLabel(self.csv_import_page)
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.horizontalLayout_2.addWidget(self.label_6)
        self.csv_encoding = QtGui.QComboBox(self.csv_import_page)
        self.csv_encoding.setObjectName(_fromUtf8("csv_encoding"))
        self.horizontalLayout_2.addWidget(self.csv_encoding)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        MapNamesWizard.addPage(self.csv_import_page)
        self.matching_process_page = QtGui.QWizardPage()
        self.matching_process_page.setObjectName(_fromUtf8("matching_process_page"))
        self.verticalLayout_8 = QtGui.QVBoxLayout(self.matching_process_page)
        self.verticalLayout_8.setObjectName(_fromUtf8("verticalLayout_8"))
        self.groupBox_4 = QtGui.QGroupBox(self.matching_process_page)
        self.groupBox_4.setObjectName(_fromUtf8("groupBox_4"))
        self.verticalLayout_7 = QtGui.QVBoxLayout(self.groupBox_4)
        self.verticalLayout_7.setObjectName(_fromUtf8("verticalLayout_7"))
        self.upgrade_none = QtGui.QRadioButton(self.groupBox_4)
        self.upgrade_none.setObjectName(_fromUtf8("upgrade_none"))
        self.verticalLayout_7.addWidget(self.upgrade_none)
        self.upgrade_nominal = QtGui.QRadioButton(self.groupBox_4)
        self.upgrade_nominal.setChecked(True)
        self.upgrade_nominal.setObjectName(_fromUtf8("upgrade_nominal"))
        self.verticalLayout_7.addWidget(self.upgrade_nominal)
        self.upgrade_all = QtGui.QRadioButton(self.groupBox_4)
        self.upgrade_all.setChecked(False)
        self.upgrade_all.setObjectName(_fromUtf8("upgrade_all"))
        self.verticalLayout_7.addWidget(self.upgrade_all)
        self.verticalLayout_8.addWidget(self.groupBox_4)
        self.groupBox_3 = QtGui.QGroupBox(self.matching_process_page)
        self.groupBox_3.setObjectName(_fromUtf8("groupBox_3"))
        self.verticalLayout_6 = QtGui.QVBoxLayout(self.groupBox_3)
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        self.preferaccepted_all = QtGui.QRadioButton(self.groupBox_3)
        self.preferaccepted_all.setObjectName(_fromUtf8("preferaccepted_all"))
        self.verticalLayout_6.addWidget(self.preferaccepted_all)
        self.preferaccepted_noauth = QtGui.QRadioButton(self.groupBox_3)
        self.preferaccepted_noauth.setChecked(True)
        self.preferaccepted_noauth.setObjectName(_fromUtf8("preferaccepted_noauth"))
        self.verticalLayout_6.addWidget(self.preferaccepted_noauth)
        self.preferaccepted_none = QtGui.QRadioButton(self.groupBox_3)
        self.preferaccepted_none.setObjectName(_fromUtf8("preferaccepted_none"))
        self.verticalLayout_6.addWidget(self.preferaccepted_none)
        self.verticalLayout_8.addWidget(self.groupBox_3)
        self.auth_lax = QtGui.QCheckBox(self.matching_process_page)
        self.auth_lax.setChecked(True)
        self.auth_lax.setObjectName(_fromUtf8("auth_lax"))
        self.verticalLayout_8.addWidget(self.auth_lax)
        self.user_choice = QtGui.QCheckBox(self.matching_process_page)
        self.user_choice.setObjectName(_fromUtf8("user_choice"))
        self.verticalLayout_8.addWidget(self.user_choice)
        MapNamesWizard.addPage(self.matching_process_page)
        self.output_page = QtGui.QWizardPage()
        self.output_page.setObjectName(_fromUtf8("output_page"))
        self.verticalLayout_2 = QtGui.QVBoxLayout(self.output_page)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.widget = QtGui.QWidget(self.output_page)
        self.widget.setObjectName(_fromUtf8("widget"))
        self.verticalLayout_10 = QtGui.QVBoxLayout(self.widget)
        self.verticalLayout_10.setMargin(0)
        self.verticalLayout_10.setObjectName(_fromUtf8("verticalLayout_10"))
        self.taxadata = QtGui.QCheckBox(self.widget)
        self.taxadata.setChecked(True)
        self.taxadata.setObjectName(_fromUtf8("taxadata"))
        self.verticalLayout_10.addWidget(self.taxadata)
        self.horizontalWidget_5 = QtGui.QWidget(self.widget)
        self.horizontalWidget_5.setEnabled(True)
        self.horizontalWidget_5.setObjectName(_fromUtf8("horizontalWidget_5"))
        self.horizontalLayout_7 = QtGui.QHBoxLayout(self.horizontalWidget_5)
        self.horizontalLayout_7.setMargin(0)
        self.horizontalLayout_7.setObjectName(_fromUtf8("horizontalLayout_7"))
        self.taxadata_file = QtGui.QLineEdit(self.horizontalWidget_5)
        self.taxadata_file.setObjectName(_fromUtf8("taxadata_file"))
        self.horizontalLayout_7.addWidget(self.taxadata_file)
        self.taxadata_browse = QtGui.QPushButton(self.horizontalWidget_5)
        self.taxadata_browse.setObjectName(_fromUtf8("taxadata_browse"))
        self.horizontalLayout_7.addWidget(self.taxadata_browse)
        self.verticalLayout_10.addWidget(self.horizontalWidget_5)
        self.verticalLayout_2.addWidget(self.widget)
        self.widget_2 = QtGui.QWidget(self.output_page)
        self.widget_2.setObjectName(_fromUtf8("widget_2"))
        self.verticalLayout_11 = QtGui.QVBoxLayout(self.widget_2)
        self.verticalLayout_11.setMargin(0)
        self.verticalLayout_11.setObjectName(_fromUtf8("verticalLayout_11"))
        self.mappings = QtGui.QCheckBox(self.widget_2)
        self.mappings.setObjectName(_fromUtf8("mappings"))
        self.verticalLayout_11.addWidget(self.mappings)
        self.horizontalWidget_4 = QtGui.QWidget(self.widget_2)
        self.horizontalWidget_4.setEnabled(False)
        self.horizontalWidget_4.setObjectName(_fromUtf8("horizontalWidget_4"))
        self.horizontalLayout_9 = QtGui.QHBoxLayout(self.horizontalWidget_4)
        self.horizontalLayout_9.setMargin(0)
        self.horizontalLayout_9.setObjectName(_fromUtf8("horizontalLayout_9"))
        self.mappings_file = QtGui.QLineEdit(self.horizontalWidget_4)
        self.mappings_file.setObjectName(_fromUtf8("mappings_file"))
        self.horizontalLayout_9.addWidget(self.mappings_file)
        self.mappings_browse = QtGui.QPushButton(self.horizontalWidget_4)
        self.mappings_browse.setObjectName(_fromUtf8("mappings_browse"))
        self.horizontalLayout_9.addWidget(self.mappings_browse)
        self.verticalLayout_11.addWidget(self.horizontalWidget_4)
        self.verticalLayout_2.addWidget(self.widget_2)
        self.widget_3 = QtGui.QWidget(self.output_page)
        self.widget_3.setObjectName(_fromUtf8("widget_3"))
        self.verticalLayout_9 = QtGui.QVBoxLayout(self.widget_3)
        self.verticalLayout_9.setMargin(0)
        self.verticalLayout_9.setObjectName(_fromUtf8("verticalLayout_9"))
        self.log = QtGui.QCheckBox(self.widget_3)
        self.log.setObjectName(_fromUtf8("log"))
        self.verticalLayout_9.addWidget(self.log)
        self.horizontalWidget_3 = QtGui.QWidget(self.widget_3)
        self.horizontalWidget_3.setEnabled(False)
        self.horizontalWidget_3.setObjectName(_fromUtf8("horizontalWidget_3"))
        self.horizontalLayout_8 = QtGui.QHBoxLayout(self.horizontalWidget_3)
        self.horizontalLayout_8.setMargin(0)
        self.horizontalLayout_8.setObjectName(_fromUtf8("horizontalLayout_8"))
        self.log_file = QtGui.QLineEdit(self.horizontalWidget_3)
        self.log_file.setObjectName(_fromUtf8("log_file"))
        self.horizontalLayout_8.addWidget(self.log_file)
        self.log_browse = QtGui.QPushButton(self.horizontalWidget_3)
        self.log_browse.setObjectName(_fromUtf8("log_browse"))
        self.horizontalLayout_8.addWidget(self.log_browse)
        self.verticalLayout_9.addWidget(self.horizontalWidget_3)
        self.verticalLayout_2.addWidget(self.widget_3)
        self.matched_ds = QtGui.QCheckBox(self.output_page)
        self.matched_ds.setObjectName(_fromUtf8("matched_ds"))
        self.verticalLayout_2.addWidget(self.matched_ds)
        self.label_5 = QtGui.QLabel(self.output_page)
        self.label_5.setWordWrap(True)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.verticalLayout_2.addWidget(self.label_5)
        MapNamesWizard.addPage(self.output_page)
        self.label.setBuddy(self.namefield)
        self.preview_label.setBuddy(self.preview)

        self.retranslateUi(MapNamesWizard)
        QtCore.QObject.connect(self.from_dataset, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.taxa_dataset.setEnabled)
        QtCore.QObject.connect(self.from_csv, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.from_csv_file.setEnabled)
        QtCore.QObject.connect(self.from_csv, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.from_csv_browse.setEnabled)
        QtCore.QObject.connect(self.auth_separate, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.authfield.setEnabled)
        QtCore.QObject.connect(self.taxadata, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.horizontalWidget_5.setEnabled)
        QtCore.QObject.connect(self.mappings, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.horizontalWidget_4.setEnabled)
        QtCore.QObject.connect(self.log, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.horizontalWidget_3.setEnabled)
        QtCore.QObject.connect(self.to_dataset, QtCore.SIGNAL(_fromUtf8("toggled(bool)")), self.target_dataset.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(MapNamesWizard)

    def retranslateUi(self, MapNamesWizard):
        MapNamesWizard.setWindowTitle(QtGui.QApplication.translate("MapNamesWizard", "Match taxa by name", None, QtGui.QApplication.UnicodeUTF8))
        self.datasets_page.setTitle(QtGui.QApplication.translate("MapNamesWizard", "Matching names", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_2.setTitle(QtGui.QApplication.translate("MapNamesWizard", "Match taxa from:", None, QtGui.QApplication.UnicodeUTF8))
        self.from_dataset.setText(QtGui.QApplication.translate("MapNamesWizard", "Dataset", None, QtGui.QApplication.UnicodeUTF8))
        self.from_csv.setText(QtGui.QApplication.translate("MapNamesWizard", "CSV file", None, QtGui.QApplication.UnicodeUTF8))
        self.from_csv_browse.setText(QtGui.QApplication.translate("MapNamesWizard", "Browse...", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("MapNamesWizard", "Reading directly from a CSV file is recommended for very large datasets, which may not fit into the computer\'s memory, or for datasets of individual samples, specimens etc. where the same name may appear several times.", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_5.setTitle(QtGui.QApplication.translate("MapNamesWizard", "Match to names in:", None, QtGui.QApplication.UnicodeUTF8))
        self.to_dataset.setText(QtGui.QApplication.translate("MapNamesWizard", "Dataset", None, QtGui.QApplication.UnicodeUTF8))
        self.to_tnrs.setText(QtGui.QApplication.translate("MapNamesWizard", "Taxonomic Name Resolution Service (iPlant Collaborative)", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("MapNamesWizard", "Using the TNRS with data from a CSV file will run through the file twice, first to collect the names, then to match each line.", None, QtGui.QApplication.UnicodeUTF8))
        self.csv_import_page.setTitle(QtGui.QApplication.translate("MapNamesWizard", "CSV columns", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("MapNamesWizard", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:8pt;\">Please select which columns contain the names (e.g. </span><span style=\" font-size:8pt; font-style:italic;\">Vigna radiata</span><span style=\" font-size:8pt;\">) and the names\' authorities (e.g. \'(L.) R. Wilczek\').</span></p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("MapNamesWizard", "Name column:", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("MapNamesWizard", "Authorities:", None, QtGui.QApplication.UnicodeUTF8))
        self.noauth.setText(QtGui.QApplication.translate("MapNamesWizard", "None", None, QtGui.QApplication.UnicodeUTF8))
        self.auth_with_name.setText(QtGui.QApplication.translate("MapNamesWizard", "In column with species", None, QtGui.QApplication.UnicodeUTF8))
        self.auth_separate.setText(QtGui.QApplication.translate("MapNamesWizard", "In separate column:", None, QtGui.QApplication.UnicodeUTF8))
        self.preview_label.setText(QtGui.QApplication.translate("MapNamesWizard", "Preview", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("MapNamesWizard", "Character encoding", None, QtGui.QApplication.UnicodeUTF8))
        self.matching_process_page.setTitle(QtGui.QApplication.translate("MapNamesWizard", "Name matching options", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_4.setTitle(QtGui.QApplication.translate("MapNamesWizard", "Subspecies and varieties", None, QtGui.QApplication.UnicodeUTF8))
        self.upgrade_none.setText(QtGui.QApplication.translate("MapNamesWizard", "Strict matches only", None, QtGui.QApplication.UnicodeUTF8))
        self.upgrade_nominal.setToolTip(QtGui.QApplication.translate("MapNamesWizard", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">e.g. <span style=\" font-style:italic;\">Zea mays </span>subsp. <span style=\" font-style:italic;\">mays</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">would match <span style=\" font-style:italic;\">Zea mays</span>.</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.upgrade_nominal.setText(QtGui.QApplication.translate("MapNamesWizard", "Match nominal subspecies to species", None, QtGui.QApplication.UnicodeUTF8))
        self.upgrade_all.setToolTip(QtGui.QApplication.translate("MapNamesWizard", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">e.g. <span style=\" font-style:italic;\">Zea mays </span>subsp. <span style=\" font-style:italic;\">parviglumis</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">would match <span style=\" font-style:italic;\">Zea mays</span>.</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.upgrade_all.setText(QtGui.QApplication.translate("MapNamesWizard", "Match any subspecies to species", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_3.setTitle(QtGui.QApplication.translate("MapNamesWizard", "Automatically select accepted name", None, QtGui.QApplication.UnicodeUTF8))
        self.preferaccepted_all.setText(QtGui.QApplication.translate("MapNamesWizard", "Always", None, QtGui.QApplication.UnicodeUTF8))
        self.preferaccepted_noauth.setText(QtGui.QApplication.translate("MapNamesWizard", "When authority info is missing", None, QtGui.QApplication.UnicodeUTF8))
        self.preferaccepted_none.setText(QtGui.QApplication.translate("MapNamesWizard", "Never", None, QtGui.QApplication.UnicodeUTF8))
        self.auth_lax.setToolTip(QtGui.QApplication.translate("MapNamesWizard", "If this is selected, when there is only one match for the name, it will be used even if the authority doesn\'t match.", None, QtGui.QApplication.UnicodeUTF8))
        self.auth_lax.setText(QtGui.QApplication.translate("MapNamesWizard", "Allow mismatched authorities", None, QtGui.QApplication.UnicodeUTF8))
        self.user_choice.setText(QtGui.QApplication.translate("MapNamesWizard", "Manually choose between ambiguous matches", None, QtGui.QApplication.UnicodeUTF8))
        self.output_page.setTitle(QtGui.QApplication.translate("MapNamesWizard", "Output options", None, QtGui.QApplication.UnicodeUTF8))
        self.taxadata.setText(QtGui.QApplication.translate("MapNamesWizard", "Taxa data with new names", None, QtGui.QApplication.UnicodeUTF8))
        self.taxadata_browse.setText(QtGui.QApplication.translate("MapNamesWizard", "Browse...", None, QtGui.QApplication.UnicodeUTF8))
        self.mappings.setText(QtGui.QApplication.translate("MapNamesWizard", "Name mappings", None, QtGui.QApplication.UnicodeUTF8))
        self.mappings_browse.setText(QtGui.QApplication.translate("MapNamesWizard", "Browse...", None, QtGui.QApplication.UnicodeUTF8))
        self.log.setText(QtGui.QApplication.translate("MapNamesWizard", "Full log of matching process", None, QtGui.QApplication.UnicodeUTF8))
        self.log_browse.setText(QtGui.QApplication.translate("MapNamesWizard", "Browse...", None, QtGui.QApplication.UnicodeUTF8))
        self.matched_ds.setText(QtGui.QApplication.translate("MapNamesWizard", "Create dataset of source taxa with new names", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("MapNamesWizard", "This is not recommended when matching big datasets read directly from file.", None, QtGui.QApplication.UnicodeUTF8))

